:tocdepth: 4

Welcome to the gnucash-utilities documentation!
===============================================

:Release: |version|
:Date: |today|
:Authors: sdementen
:Project page: https://github.com/sdementen/gnucash-utilities

.. toctree::
   :maxdepth: 1

   news.rst

Contents:

.. toctree::
   :maxdepth: 2

   doc/doc.rst

The complete api documentation (apidoc) :

.. toctree::
   :maxdepth: 1

   api/modules.rst

Indices and tables
==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
